==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/marketplace/messages/pl/base.php <==
<?php

return [
    '
Module successfully disabled!
' => 'Moduł wyłączony poprawnie!',
    '
Module successfully enabled!
' => 'Moduł włączony poprawnie!',
    '
No active Professional Edition license found!
' => 'Nie znaleziono aktywnej licencji Edycji Profesjonalnej',
    '
PROFESSIONAL EDITION
' => 'EDYCJA PROFESJONALNA',
    '
The license could not be activated:
' => 'Licencja nie może zostać aktywowana:',
    '
The license was successfully activated!

' => 'Licencja została pomyślnie aktywowana!',
    '
The license was successfully removed!

' => 'Licencja została prawidłowo usunięta!',
    '--- Disable module: {moduleId} ---

' => '--- Wyłącz moduł: {moduleId} ---',
    '--- Enable module: {moduleId} ---

' => '--- Włącz moduł: {moduleId} ---',
    '<strong>Activate</strong> your Professional Edition' => '<strong>Aktywuj</strong> swoją Wersję Profesjonalną',
    'Add purchased module by licence key' => 'Dodaj zakupiony moduł wprowadzając klucz licencyjny',
    'All {moduleId} module content will be deleted. Continue?' => 'Całą zawartość modułu {moduleId} zostanie usunięta. Kontynuować?',
    'Buy' => 'Kup',
    'Buy (%price%)' => 'Kup (%price%)',
    'Could not connect to HumHub API!
' => 'Nie można połączyć z API HumHub!',
    'Could not connect to licence server!' => 'Nie można połączyć z serwerem licencyjnym!',
    'Could not extract module!' => 'Nie można wypakować modułu!',
    'Could not remove old module path!' => 'Nie można usunąć starej ścieżki modułu!',
    'Could not update licence. Error: ' => 'Nie można uaktualnić licencji. Błąd:',
    'Download of module failed!' => 'Pobieranie modułu nie powiodło się!',
    'Edit licence' => 'Edytuj licencję',
    'If this Module is additionally marked as <strong>"Community"</strong> it is neither tested nor monitored by the HumHub project team.' => 'Jeżeli ten moduł jest oznaczony jako <strong>"Społeczność"</strong> oznacza to, że nie jest testowany ani monitorowany przez zespół HumHub.',
    'Install' => 'Zainstaluj',
    'Installed' => 'Zainstalowane',
    'Installing module...' => 'Instaluję moduł...',
    'Invalid module licence key!
' => 'Błędny klucz licencyjny modułu!',
    'Latest version:' => 'Ostatnia wersja:',
    'Licence Key:' => 'Klucz licencyjny:',
    'Licence key' => 'Klucz licencji',
    'Licenced for max. {number} users.' => 'Licencjonowanie dla max. {number} użytkowników.',
    'Licenced to:' => 'Licencjonowane dla:',
    'Marketplace' => 'Sklep aplikacji',
    'Max. users:' => 'Maksymalnie użytkowników:',
    'Module directory %modulePath% is not writeable!' => 'Katalog modułu %modulePath% nie jest zapisywalny!',
    'Module download failed! (%error%)' => 'Nie powiodło się pobieranie modułu! (%error%)',
    'Module licence added!
' => 'Dodano licencję modułu!',
    'Module licence key cannot be empty!
' => 'Klucz licencji modułu nie może być pusty!',
    'Module not found or activated!
' => 'Moduł nie odnaleziony lub aktywowany!',
    'Module not found!
' => 'Moduł nie odnaleziony!',
    'More info' => 'Więcej informacji',
    'No compatible module version found!' => 'Nie znaleziono kompatybilnej wersji modułu!',
    'No license key? Find out more about the {pro} or contact us.' => 'Brak klucza licencyjnego? Dowiedz się więcej o {pro} lub skontaktuj się z nami.',
    'No purchased modules found!' => 'Nie znaleziono zakupionych modułów!',
    'Ok' => 'Ok',
    'Professional Edition is activated!' => 'Edycja Profesjonalna aktywowana!',
    'Register' => 'Zarejestruj się',
    'Remove licence key' => 'Usuń klucz licencyjny',
    'Save and update' => 'Zapisz i aktualizuj',
    'The HumHub project does not guarantee the functionality, quality or the continuous development of this Module.' => 'Zespół HumHub nie gwarantuje funkcjonalności, jakości lub ciągłości wsparcia tego modułu.',
    'Third-party' => 'Inni dostawcy',
    'Third-party Modules are not covered by Professional Edition agreements.' => 'Moduły osób trzecich nie są wspierane przez umowę Profesjonalnej Edycji.',
    'Third-party disclaimer' => 'Oświadczenie osób trzecich',
    'This Module was developed by a third-party.' => 'Ten moduł został opracowany przez osoby trzecie.',
    'Update' => 'Aktualizuj',
    'Upgrade to Professional Edition' => 'Ulepsz do Wersji Profesjonalnej',
    'Version:' => 'Wersja:',
    'A new update is available (HumHub %version%)!' => '',
    'Add Licence Key' => '',
    'All' => '',
    'Available Updates' => '',
    'Categories' => '',
    'Changelog' => '',
    'Community' => '',
    'Featured' => '',
    'Learn more' => '',
    'New' => '',
    'Not Installed' => '',
    'Official' => '',
    'Partner' => '',
    'Professional Edition' => '',
    'Stop updating' => '',
    'Tags' => '',
    'Update all' => '',
    'Your HumHub installation is up to date!' => '',
];

==> humhub-1.15.0-beta.2.tar.gz: humhub-1.15.0-beta.2/protected/humhub/modules/marketplace/messages/pl/base.php <==
<?php

return [
    '
Module successfully disabled!
' => 'Moduł wyłączony poprawnie!',
    '
Module successfully enabled!
' => 'Moduł włączony poprawnie!',
    '
No active Professional Edition license found!
' => 'Nie znaleziono aktywnej licencji Edycji Profesjonalnej',
    '
The license could not be activated:
' => 'Licencja nie może zostać aktywowana:',
    '
The license was successfully activated!

' => 'Licencja została pomyślnie aktywowana!',
    '
The license was successfully removed!

' => 'Licencja została prawidłowo usunięta!',
    '--- Disable module: {moduleId} ---

' => '--- Wyłącz moduł: {moduleId} ---',
    '--- Enable module: {moduleId} ---

' => '--- Włącz moduł: {moduleId} ---',
    '<strong>Activate</strong> your Professional Edition' => '<strong>Aktywuj</strong> swoją Wersję Profesjonalną',
    'Activate' => 'Aktywuj',
    'Activated' => 'Aktywowane',
    'Add purchased module by licence key' => 'Dodaj zakupiony moduł wprowadzając klucz licencyjny',
    'All' => 'Wszystko',
    'All {moduleId} module content will be deleted. Continue?' => 'Całą zawartość modułu {moduleId} zostanie usunięta. Kontynuować?',
    'Buy' => 'Kup',
    'Buy (%price%)' => 'Kup (%price%)',
    'Configure' => 'Konfiguruj',
    'Could not connect to HumHub API!
' => 'Nie można połączyć z API HumHub!',
    'Could not connect to licence server!' => 'Nie można połączyć z serwerem licencyjnym!',
    'Could not extract module!' => 'Nie można wypakować modułu!',
    'Could not find requested module!' => 'Nie można znaleźć żądanego modułu.',
    'Could not remove old module path!' => 'Nie można usunąć starej ścieżki modułu!',
    'Could not update licence. Error: ' => 'Nie można uaktualnić licencji. Błąd:',
    'Download of module failed!' => 'Pobieranie modułu nie powiodło się!',
    'Edit licence' => 'Edytuj licencję',
    'General Settings' => 'Główne Ustawienia',
    'If this Module is additionally marked as <strong>"Community"</strong> it is neither tested nor monitored by the HumHub project team.' => 'Jeżeli ten moduł jest oznaczony jako <strong>"Społeczność"</strong> oznacza to, że nie jest testowany ani monitorowany przez zespół HumHub.',
    'Information' => 'Informacje',
    'Install' => 'Zainstaluj',
    'Installed' => 'Zainstalowane',
    'Invalid module licence key!
' => 'Błędny klucz licencyjny modułu!',
    'Latest version:' => 'Ostatnia wersja:',
    'Licence Key:' => 'Klucz licencyjny:',
    'Licence key' => 'Klucz licencji',
    'Licenced for max. {number} users.' => 'Licencjonowanie dla max. {number} użytkowników.',
    'Licenced to:' => 'Licencjonowane dla:',
    'License not found or expired. Please contact the module publisher.' => 'Nie znaleziono licencji lub licencja wygasła. Skontaktuj się z wydawcą modułu.',
    'Marketplace' => 'Sklep aplikacji',
    'Max. users:' => 'Maksymalnie użytkowników:',
    'Module directory %modulePath% is not writeable!' => 'Katalog modułu %modulePath% nie jest zapisywalny!',
    'Module download failed! (%error%)' => 'Nie powiodło się pobieranie modułu! (%error%)',
    'Module licence added!
' => 'Dodano licencję modułu!',
    'Module licence key cannot be empty!
' => 'Klucz licencji modułu nie może być pusty!',
    'Module not found or activated!
' => 'Moduł nie odnaleziony lub aktywowany!',
    'Module not found!
' => 'Moduł nie odnaleziony!',
    'More info' => 'Więcej informacji',
    'New' => 'Nowe',
    'No compatible module version found!' => 'Nie znaleziono kompatybilnej wersji modułu!',
    'No license key? Find out more about the {pro} or contact us.' => 'Brak klucza licencyjnego? Dowiedz się więcej o {pro} lub skontaktuj się z nami.',
    'No modules installed yet. Install some to enhance the functionality!' => 'Brak zainstalowanych modułów. Zainstaluj jakieś aby zwiększyć funkcjonalność!',
    'No purchased modules found!' => 'Nie znaleziono zakupionych modułów!',
    'Ok' => 'Ok',
    'Professional Edition is activated!' => 'Edycja Profesjonalna aktywowana!',
    'Register' => 'Zarejestruj się',
    'Remove licence key' => 'Usuń klucz licencyjny',
    'Save and update' => 'Zapisz i aktualizuj',
    'Search' => 'Szukaj',
    'Search...' => 'Szukaj...',
    'Settings' => 'Ustawienia',
    'Tags' => 'Tagi',
    'The HumHub project does not guarantee the functionality, quality or the continuous development of this Module.' => 'Zespół HumHub nie gwarantuje funkcjonalności, jakości lub ciągłości wsparcia tego modułu.',
    'Third-party' => 'Inni dostawcy',
    'Third-party Modules are not covered by Professional Edition agreements.' => 'Moduły osób trzecich nie są wspierane przez umowę Profesjonalnej Edycji.',
    'Third-party disclaimer' => 'Oświadczenie osób trzecich',
    'This Module was developed by a third-party.' => 'Ten moduł został opracowany przez osoby trzecie.',
    'Try other keywords or remove filters.' => 'Spróbuj inne słowa kluczowe lub usuń filtry.',
    'Update' => 'Aktualizuj',
    'Update successful' => 'Aktualizacja ukończona pomyślnie',
    'Upgrade to Professional Edition' => 'Ulepsz do Wersji Profesjonalnej',
    'Version:' => 'Wersja:',
    '<strong>General</strong> Settings' => '',
    'A new update is available (HumHub %version%)!' => '',
    'Activate now' => '',
    'Add Licence Key' => '',
    'After installing the required module, all you have to do is activate it. After that you can instantly start using the module or function. Please note that some modules need to be configured before use.' => '',
    'Allow module versions in beta status' => '',
    'Available Updates' => '',
    'Categories' => '',
    'Changelog' => '',
    'Community' => '',
    'Could not connect to HumHub API!' => '',
    'Could not find the requested module!' => '',
    'Deprecated' => '',
    'Featured' => '',
    'Find all the modules you can add to your network in our HumHub Marketplace. Discover numerous add-ons and features that customize the software and give you the possibility to configure your network to your needs.' => '',
    'Great!' => '',
    'Invalid module licence key!' => '',
    'Learn more' => '',
    'Marketplace is disabled.' => '',
    'Module "{moduleName}" has been updated to version {newVersion} successfully.' => '',
    'Module <strong>activated</strong>' => '',
    'Module <strong>installed</strong>' => '',
    'Module configuration' => '',
    'Module is <strong>installing...</strong>' => '',
    'Module licence added!' => '',
    'No modules found.' => '',
    'Official' => '',
    'PROFESSIONAL EDITION' => '',
    'Partner' => '',
    'Professional Edition' => '',
    'Stop updating' => '',
    'Uninstalled' => '',
    'Update all' => '',
    'We are almost there! As a final step, we recommend that you take a look at the module configuration, where you will find numerous configuration options, some of which are required.' => '',
    'Well done! To make the module available within your network, you will also need to activate it. Do you want to activate it now?' => '',
    'Well done! You have successful installed an activated the module!' => '',
    'Would you like to jump straight to it?' => '',
    'Your HumHub installation is up to date!' => '',
];
